"""\
PEP INFO

PEP 281 -- Loop Counter Iteration with range and xrange
Status: Rejected
Created: 2002-02-11

MODULE INFO

This module changes range into a function that runs like specified in PEP 281.

REFERENCES

PEP 281: <https://www.python.org/dev/peps/pep-0281/>
"""
PEP = 281
import builtins as _b

def range(*args):
    a = []
    for arg in args:
        try:
            a.append(arg.__index__())
        except (AttributeError, ValueError):
            try:
                a.append(len(arg))
            except (TypeError, ValueError):
                raise TypeError(f'TypeError: {type(arg).__name__!r} object '
                                'cannot be interpreted '
                                'as an integer') from None
    return _b.range(*a)



from sys import version_info as _vi
__doc__ = ("""\
PEP INFO

PEP 265 -- Sorting Dictionaries by Value
Status: Rejected
Created: 2001-08-08

MODULE INFO

This module implements the sorting function on dicts in PEP 265.
However, its __name__ is changed to itemlist because it returns a list,
not the regular items() type in Python 3. items() is an alias. Also,
since dicts are ordered in supported versions, the sortby argument
accepts -1 (ORIGINAL), 0 (KEYS) and 1 (VALUES).
The `key` and `reverse` parameters are also added to match sorted().
Note that the builtins sorted()
function is more flexable, thus we recommend it instead of itemlist().

REFERENCES

PEP 265: <https://www.python.org/dev/peps/pep-0265/>
Related:""" +
f'sorted: <https://docs.python.org/'
f'{".".join(map(str, _vi[:2]))}/library/functions.html#sorted>')
PEP = 265
import builtins as _b

sorted = sorted  # Recommended
def _sort(items: list, index: int, *,
          key=None, reverse: bool = False) -> list:
    if key is None:
        return _b.sorted(items,  # Prevent sorted() overwrite
                         key=(lambda x, i=index: x[i]),
                         reverse=reverse)
    return _b.sorted(items,
                     key=(lambda x, i=index: key(x[i])),
                     reverse=reverse)
ORIGINAL, KEYS, VALUES = -1, 0, 1
# Since dicts are now ordered, an option to not sort is needed
def itemlist(dic, sortby: int = ORIGINAL, *,
             key=None, reverse: bool = False) -> list:
    i = list(dic.items())
    if sortby <= ORIGINAL:
        return (i[::-1] if reverse else i)
    return _sort(i, (not not sortby),
                 key=key, reverse=reverse)
items = itemlist



"""\
PEP INFO

PEP 336 -- Make None callable
Status: Rejected
Created: 2004-10-28

MODULE INFO

This module adds NoneType that makes None callable, 
and instance none (None is a keyword). This breaks the `x is None` usage, 
so `isNone(obj)` checks if obj is None or none.

REFERENCES

PEP 336: <https://www.python.org/dev/peps/pep-0336/>
"""
PEP = 336

class _singleton(type):
    # None is a singleton
    _instances = {}
    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__(*args, **kwargs)
        return cls._instances[cls]
class NoneType(metaclass=_singleton):
    def __repr__(self) -> str:
        return 'None'
    __str__ = __repr__
    def __call__(self, *args, **kwargs) -> 'NoneType':
        return self
    def __eq__(self, other) -> bool:
        return isinstance(other, type(self)) or other is None
none = NoneType()
def isNone(object) -> bool:
    return object is none or object is None



"""\
PEP INFO

PEP 335 -- Overloadable Boolean Operators
Status: Rejected
Created: 2004-08-29

MODULE INFO

This module implements the and_/AND, or_/OR & not_/NOT functions that 
check for the dunder methods specified in PEP 335. NeedOtherOperand is 
also implemented. These functions also have "plain" versions in the 
`plain` namespace that does not do short-circuiting.

REFERENCES

PEP 335: <https://www.python.org/dev/peps/pep-0335/>
"""
PEP = 335

import warnings as _w
class _singleton(type):
    # NeedOtherOperand is a singleton
    _instances = {}
    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__(*args, **kwargs)
        return cls._instances[cls]
class NeedOtherOperandType(metaclass=_singleton):
    def __repr__(self) -> str:
        return 'NeedOtherOperand'
    __str__ = __repr__
    def __hash__(self):
        return hash(id(self))
NeedOtherOperand = NeedOtherOperandType()
_notimplemented_warning_message = ('NotImplemented should not be used '
                                   'in a boolean context. Did you mean to '
                                   'return NeedOtherOperand?')
def NOT(a) -> bool:
    a_not = getattr(a, '__not__', None)
    if a_not is None:
        return not a
    a_return = a_not()
    if a_return is NeedOtherOperand or a_return is NotImplemented:
        return not a
    return bool(a_return)
not_ = NOT
class plain:
    def __init__(self):
        raise Exception('plain cannot be initialized')
    @staticmethod
    def AND(a, b):
        a_and = getattr(a, '__and2__', None)
        if a_and is not None:
            a_return = a_and(b)
            if a_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        DeprecationWarning, 2)
            if a_return is not NeedOtherOperand:
                return a_return
        b_rand = getattr(b, '__rand2__', None)
        if b_rand is not None:
            b_return = b_rand(a)
            if b_return is not NeedOtherOperand:
                return b_return
        with _w.catch_warnings():
            return a and b
    and_ = AND
    @staticmethod
    def OR(a, b):
        a_or = getattr(a, '__or2__', None)
        if a_or is not None:
            a_return = a_or(b)
            if a_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        DeprecationWarning, 2)
            if a_return is not NeedOtherOperand:
                return a_return
        b_ror = getattr(b, '__ror2__', None)
        if b_ror is not None:
            b_return = b_ror(a)
            if b_return is NotImplemented:
                _w.warn(_notimplemented_warning_message,
                        DeprecationWarning, 2)
            if b_return is not NeedOtherOperand:
                return a_return
        with _w.catch_warnings():
            return a or b
    or_ = OR
    NOT = not_ = staticmethod(NOT)
def AND(a, b):
    a_and = getattr(a, '__and1__', None)
    if a_and is None:
        return plain.AND(a, b)
    a_return = a_and()
    if a_return is NeedOtherOperand:
        return plain.AND(a, b)
    if a_return is NotImplemented:
        _w.warn(_notimplemented_warning_message,
                DeprecationWarning, 2)
    return a_return
and_ = AND
def OR(a, b):
    a_or = getattr(a, '__or1__', None)
    if a_or is None:
        return plain.OR(a, b)
    a_return = a_or()
    if a_return is NeedOtherOperand:
        return plain.OR(a, b)
    if a_return is NotImplemented:
        _w.warn(_notimplemented_warning_message,
                DeprecationWarning, 2)
    return a_return
or_ = OR



"""\
PEP INFO

PEP 313 -- Adding Roman Numeral Literals to Python
Status: Rejected
Created: 2003-04-01

MODULE INFO

This module implements the to_roman() function to convert numbers or fractions 
to roman numbers, and the from_roman() function to convert roman 
numbers to numbers or fractions. There are 3 modes:
- CLASSIC: Plain I, V, X etc.
- MODERN: Allow IV (4), CM (900) etc. in addition to CLASSIC
- LARGE: Allow up to 3 leading underscores before letter to mean ×1000,
         for example _M -> 1000*1000 = 1000000 in addition to MODERN
The `zero` parameters control handling of zero. If None, 0 raises an error; 
else it returns the value in to_roman(), and returns 0 if s is equal to it 
in from_roman(). You can control the global default (first set to None) with 
the default_zero attribute.

REFERENCES

PEP 313: <https://www.python.org/dev/peps/pep-0313/>
"""
from numbers import Rational as _R, Integral as _I
from fractions import Fraction as _F
MODERN, CLASSIC, LARGE = 'modern', 'classic', 'large'
classic_dict = {1000: 'M',
                500: 'D',
                100: 'C',
                50: 'L',
                10: 'X',
                5: 'V',
                1: 'I'}
modern_dict = {1000: 'M',
               900: 'CM',
               500: 'D',
               400: 'CD',
               100: 'C',
               90: 'XC',
               50: 'L',
               40: 'XL',
               10: 'X',
               9: 'IX',
               5: 'V',
               4: 'IV',
               1: 'I'}
large_dict = {1_000_000_000_000: '___M',
              500_000_000_000: '__D',
              100_000_000_000: '___C',
              50_000_000_000: '___L',
              10_000_000_000: '___X',
              1_000_000_000: '__M',
              500_000_000: '__D',
              100_000_000: '__C',
              50_000_000: '__L',
              10_000_000: '__X',
              1_000_000: '_M',
              500_000: '_D',
              100_000: '_C',
              50_000: '_L',
              10_000: '_X'}
large_dict.update(modern_dict)
DIGITS = set(classic_dict.values())
default_zero = None
def to_roman(x: _R, mode: str = MODERN, *, zero=default_zero) -> str:
    if mode not in (MODERN, CLASSIC, LARGE):
        raise ValueError(f'Invalid mode {mode!r}')
    if isinstance(x, _R) and not isinstance(x, (_I, float)):
        return f'{to_roman(x.numerator)}/{to_roman(x.denominator)}'
    try:
        x = int(x)
    except Exception as e:
        try:
            x = int(x, 0)
        except Exception:
            raise e from None
    if x == 0:
        if zero is None:
            raise ValueError('x cannot be 0')
        return zero
    if x < 0:
        return f'-{to_roman(abs(x))}'
    r = {CLASSIC: classic_dict,
         MODERN: modern_dict,
         LARGE: large_dict}[mode]
    lis = []
    for i in r:
        a, x = divmod(x, i)
        lis.append(r[i] * a)
        if x <= 0:
            break
    return ''.join(lis)
def from_roman(s: str, *, zero=default_zero) -> _R:
    if zero is not None and s == zero:
        return 0
    if not isinstance(s, str):
        raise TypeError(f'Invalid roman string type: {type(s).__name__!r}')
    if not s:
        raise ValueError('Roman string cannot be blank')
    if s[0] == '-':
        return -from_roman(s[1:])
    if s[0] == '+':
        return +from_roman(s[1:])
    if s.count('/') == 1:
        return _F(from_roman(s.split('/')[0]),
                  from_roman(s.split('/')[1]))
    s = s.upper()
    if (set(s) - DIGITS - {'_'}) or not (set(s)-{'_'}):
        raise ValueError(f'Invalid roman numeral: {s!r}')
    result = i = 0
    for integer, num in large_dict.items():
        ln = len(num)
        while s[i:i+ln] == num:
            result += integer
            i += ln
    if result == 0:
        raise ValueError(f'Invalid roman numeral: {s!r}')
    return result
# def __getattr__(name: str):
#    raise AttributeError(f'module {__name__!r} has no attribute {name!r}')



__version__ = '0.6.0c2'
import importlib as _imp
from collections import namedtuple as _nt
from itertools import chain as _chain
import warnings as _w
# Typing
from typing import Generator as _Gen, Optional as _O
from types import ModuleType as _Module

def pep(n: int) -> _Module:
    if (not isinstance(n, int)) or n < 0 or n > 9999:
        raise ValueError(f'Invalid PEP number {n!r}')
    try:
        try:
            return _imp.import_module(f'..pep{n}', 'rejected_peps.subpkg')
        except ImportError:
            return _imp.import_module(f'pep{n}')
    except ImportError:
        raise ValueError(f'PEP {n!r} not supported') from None
SUPPORTED = frozenset((204, 211, 212, 259,
                       265, 276, 281, 294,
                       303, 313, 326, 335,
                       336, 349, 351, 416,
                       559, 754, 3140))
# ↑ Not automatic because it's too slow
def search(*s, strict: bool = False) -> _Gen:
    global SUPPORTED
    if not s:
        return
    if any((not isinstance(i, str)) for i in s):
        raise TypeError('Invalid argument(s)')
    func = ((lambda n: n) if strict else str.lower)
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        if all((func(x) in func(t)) for x in s):
            yield pep
def _search_any(*s, strict: bool = False) -> _Gen:
    for i in _chain.from_iterable(search(x, strict=strict) for x in s):
        yield i
search.any = _search_any
def _search_one(*s, strict: bool = True) -> _O[int]:
    global SUPPORTED
    if not s:
        return
    func = ((lambda n: n) if strict else str.lower)
    xs = []
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        j = 0
        for x in s:
            try:
                j += (func(x) in t.lower() or
                      func(x) in func(t) or
                      func(x) in t.upper())
            except TypeError:
                message = ["args must be type 'str', ",
                           f"not {type(x).__name__!r}"]
                if isinstance(x, bool):
                    message.append(f'. Did you mean strict={x!r}?')
                raise TypeError(''.join(message)) from None
        if j == len(s):
            if not strict:
                return pep
            xs.append(pep)
    if not strict:
        return None
    if xs[1:]:
        raise ValueError(f'More than 1 match: {", ".join(map(str, xs))} ({len(xs)})')
    if not xs:
        raise ValueError(f'No match found')
    return xs[0]
search.one = _search_one
def search_one(*args, **kwargs):
    _w.warn('search_one() is deprecated and will be removed in v0.9.',
            PendingDeprecationWarning, 2)
    return search.one(*args, **kwargs)
def _search_one_any(*s, strict: bool = True) -> _O[int]:
    global SUPPORTED
    if not s:
        return
    func = ((lambda n: n) if strict else str.lower)
    xs = []
    for pep in sorted(SUPPORTED):
        t = info(pep).title
        for x in s:
            try:
                cond = (func(x) in t.lower() or
                        func(x) in func(t) or
                        func(x) in t.upper())
                if cond:
                    break
            except TypeError:
                message = ["args must be type 'str', ",
                           f"not {type(x).__name__!r}"]
                if isinstance(x, bool):
                    message.append(f'. Did you mean strict={x!r}?')
                raise TypeError(''.join(message)) from None
        else:
            continue
        if not strict:
            return pep
        xs.append(pep)
    if not strict:
        return None
    if xs[1:]:
        raise ValueError(f'More than 1 match: {", ".join(map(str, xs))} ({len(xs)})')
    if not xs:
        raise ValueError(f'No match found')
    return xs[0]
search.one.any = _search_one_any
def get(*s) -> _Module:
    return pep(search.one(*s))
def _get_any(*s) -> _Module:
    return pep(search.one.any(*s))
get.any = _get_any
del _search_any
del _search_one
del _search_one_any
del _get_any

class UnavailableError(LookupError, NotImplementedError):
    pass
pepinfo = _nt('pepinfo', ('number', 'title', 'status', 'creation', 'url'))
def info(n: int) -> pepinfo:
    doc = getattr(pep(n), '__doc__', '').splitlines()
    if not doc[3:]:
        raise UnavailableError(f'Info of PEP {n!r} unavailable')
    return pepinfo(number=n,
                   title=doc[2].split(' -- ')[1],
                   status=doc[3].lstrip('Status: '),
                   creation=doc[4].lstrip('Created: '),
                   url=f'https://www.python.org/dev/peps/pep-{n:0>4}/')

def __getattr__(name):
    if name.startswith('pep'):
        try:
            p = pep(int(name[3:]))
        except (TypeError, ValueError):
            pass
        else:
            return p
    raise AttributeError(f'module {__name__!r} has no attribute {name!r}')
def __dir__() -> list:
    return sorted(set(globals().keys()) | {f'pep{n}' for n in SUPPORTED})



"""\
PEP INFO

PEP 349 -- Allow str() to return unicode strings
Status: Rejected
Created: 2005-08-02

MODULE INFO

This module changes str() to allow returning **bytes**. 
Since all strings are unicode starting from Python 3, 
the title is changed. Note that str() is made a function, 
and the three argument form is disallowed.

REFERENCES

PEP 349: <https://www.python.org/dev/peps/pep-0349/>
"""
PEP = 349
import builtins as _b
from typing import Union as _U
# NOTE: bytearrays may be supported too, but not do it yet. <2021-08-08>

def str(object='') -> _U[_b.str, bytes]:
    if isinstance(object, (_b.str, bytes)):
        return object
    r = object.__str__()
    if not isinstance(r, (_b.str, bytes)):
        raise TypeError('__str__ returned non-string or non-bytes')
    return r



"""\
PEP INFO

PEP 211 -- Adding A New Outer Product Operator
Status: Rejected
Created: 2000-07-15

MODULE INFO

This module implements a wrapper that enables the @ operator 
to mean itertools.product. Call the wrapper to get the original object.

REFERENCES

PEP 211: <https://www.python.org/dev/peps/pep-0211/>
"""
PEP = 211

from itertools import product
class wrapper:
    def __init__(self, obj):
        self._obj = obj
    def __matmul__(self, other) -> product:
        return product(self(), getattr(other, '_obj', other))
    def __rmatmul__(self, other) -> product:
        return product(getattr(other, '_obj', other), self())
    def __call__(self):
        return self._obj



"""\
PEP INFO

PEP 259 -- Omit printing newline after newline
Status: Rejected
Created: 2001-06-11

MODULE INFO

This module provides the print() function that omits the trailing 
newline of the last argument if `end` starts with '\\n'.

REFERENCES

PEP 259: <https://www.python.org/dev/peps/pep-0259/>
"""
PEP = 259

import builtins as _b
def print(*args, sep: str = ' ', end: str = '\n', flush: bool = False) -> None:
    if not args:
        return _b.print(sep=sep, end=end, flush=flush)
    # Use str.removesuffix as soon as support for Python 3.8 is dropped
    if not isinstance(end, (str, type(None))):
        raise TypeError(f'end must be None or a string, '
                        f'not {type(sep).__name__}')
    if str(args[-1]).endswith('\n') and end.startswith('\n'):
        return _b.print(*args[:-1], str(args[-1])[:-1],
                        sep=sep, end=end, flush=flush)
    return _b.print(*args, sep=sep, end=end, flush=flush)



"""\
PEP INFO

PEP 351 -- The freeze protocol
Status: Rejected
Created: 2005-04-14

MODULE INFO

This module implements the freeze() function in PEP 351. An allow_frozendict
parameter is added. If true (false by default), dicts, OrderedDicts
and defaultdicts return the manual implementation of frozendict in PEP 416
if possible.

REFERENCES

PEP 351: <https://www.python.org/dev/peps/pep-0351/>
Related:
PEP 416: <https://www.python.org/dev/peps/pep-0416/>
"""
PEP = 351

from types import MappingProxyType as _MPT
from collections import deque as _deq, OrderedDict as _OD, defaultdict as _dd
try:
    from . import pep416
except ImportError as e:
    import pep416
def freeze(obj, allow_frozendict: bool = False):
    try:
        hash(obj)
    except TypeError:
        # Since PEP is rejected, set, list etc. don't implement __freeze__,
        # so manual check is needed
        if isinstance(obj, set):
            return frozenset(obj)
        if isinstance(obj, (list, set, _deq)):
            t = tuple(obj)
            return t
        if isinstance(obj, (dict, _OD, _dd)):
            if allow_frozendict:
                # Allow using manual PEP 416 implementation from pep416 module
                d = pep416.frozendict(obj)
            else:
                d = _MPT(obj)  # MappingProxyType by default
            return d
        # Fallback
        freezer = getattr(obj, '__freeze__', None)
        if freezer is None:
            raise TypeError(f'{type(obj).__name__!r} object is not freezable')
        return freezer()
    else:
        return obj



"""\
PEP INFO

PEP 303 -- Extend divmod() for Multiple Divisors
Status: Rejected
Created: 2002-12-31

MODULE INFO

This module changes divmod() mostly following the PEP. However, divmod()
divides the divisors with the first divisor first. Last divisor first
like proposed is the rdivmod() function. The inverse_divmod function
from PEP 303 is also added.

REFERENCES

PEP 303: <https://www.python.org/dev/peps/pep-0303/>
"""
PEP = 303

def divmod(dividend, *divisors) -> tuple:
    # Mostly copied from PEP 303
    modulos = ()
    q = dividend
    while divisors:
        try:
            qd = q.__divmod__
        except AttributeError:
            raise ValueError(f"TypeError: unsupported operand type(s) "
                             f"for divmod(): {type(q).__name__!r} and "
                             f"{type(divisors[0]).__name__!r}") from None
        qr = qd(divisors[0])
        if qr is NotImplemented:
            raise ValueError(f"TypeError: unsupported operand type(s) "
                             f"for divmod(): {type(q).__name__!r} and "
                             f"{type(divisors[0]).__name__!r}")
        q, r = qr
        modulos = (r,) + modulos
        divisors = divisors[1:]
    return (q,) + modulos
def rdivmod(dividend, *divisors) -> tuple:
    return divmod(dividend, *divisors[::-1])
def inverse_divmod(seq, *factors):
    # Copied from PEP 303
    product = seq[0]
    for x, y in zip(factors, seq[1:]):
        product = product * x + y
    return product



"""\
PEP INFO

PEP 559 -- Built-in noop()
Status: Rejected
Created: 2017-09-08

MODULE INFO

This module implements the noop() function in PEP 559 that takes
any arguments and just returns None.

REFERENCES

PEP 559: <https://www.python.org/dev/peps/pep-0559/>
"""
PEP = 559

def noop(*args, **kws) -> None:
    # Copied
    return None



"""\
PEP INFO

PEP 416 -- Add a frozendict builtin type
Status: Rejected
Created: 2012-02-29

MODULE INFO

This module implements the frozendict type described in PEP 416. Note that
since dict is ordered in supported versions, frozendict is also ordered.

REFERENCES

PEP 416: <https://www.python.org/dev/peps/pep-0416/>
Related:
PEP 351: <https://www.python.org/dev/peps/pep-0351/>
"""
PEP = 416

# Cannot subclass types.MappingProxyType
class frozendict(dict):
    # Mostly copied from PEP 351 "Sample implementations"
    def __hash__(self) -> int:
        # PEP 416:
        # > However, frozendict values can be not hashable.
        # > A frozendict is hashable if and only if all values are hashable.
        hashes = [], []
        # Needs two to avoid mixing keys and values, e.g.
        # hash(frozendict({1: 2, 3: 4})) & hash(frozendict({1: 3, 2: 4}))
        for k, v in self.items():
            hashes[0].append(hash(k))
            hashes[1].append(hash(v))
        # PEP 416:
        # > · frozendict hash does not depend on the items creation order
        hashes[0].sort()
        hashes[1].sort()
        return hash((tuple(hashes[0]), tuple(hashes[1])))
    def __repr__(self) -> str:
        return f'{type(self).__name__}({super().__repr__()})'
    def __immutable(self, *args, **kwargs):
        raise TypeError(f'{type(self).__name__!r} object is immutable')
    __setitem__ = __immutable
    __delitem__ = __immutable
    clear       = __immutable
    update      = __immutable
    setdefault  = __immutable
    pop         = __immutable
    popitem     = __immutable
    def __dir__(self):
        return (set(object.__dir__(self))
                -{'__setitem__', '__delitem__',
                  'clear', 'update', 'setdefault', 'pop',
                  'popitem', f'_{type(self).__name__}__immutable'})



"""\
PEP INFO

PEP 294 -- Type Names in the types Module
Status: Rejected
Created: 2002-06-19

MODULE INFO

The apply(module=types, *, rename=underscore, strict=bool) function
adds the lowercase regular version as in the PEP to 
the module. If the new name is invalid (e.g. `lambda`), rename(name)
is called. If strict is True, then the new return value of rename()
and the type (should be str) will be checked. This is done in-place
so apply() returns None.
The underscore(), title() and original() functions are provided
for the rename parameter.
See the docstrings for more information.

REFERENCES

PEP 294: <https://www.python.org/dev/peps/pep-0294/>
"""
import keyword as _k
from typing import Optional as _O
def underscore(s: str) -> str:
    """Appends an underscore (_) to s."""
    return f'{s}_'
title = str.title
def original(s: str) -> str:
    """Returns s."""
    return s
def valid(name: str) -> bool:
    """True if name is an identifier & not a keyword. Note that non-str types return True."""
    if not isinstance(name, str):
        return True
    return _k.iskeyword(name) + (not name.isidentifier()) == 0
def apply(module=None, *, rename=underscore,
          strict: _O[bool] = None):
    types = module or __import__('types')
    if strict is None:
        strict = rename is not original
    for name in dir(types):
        if name[-4:] == 'Type' and name[:-4]:
            new_name = name[:-4].lower()
            if not valid(new_name):
                r = rename(new_name)
                if strict and not valid(r):
                    raise ValueError(f'Invalid name {r!r}')
                new_name = r
            if strict and type(r) is not str:
                # str subclasses aren't allowed
                raise TypeError(f'Invalid name {new_name!r} with type '
                                f'{type(r).__name__!r}')
            setattr(types, new_name, getattr(types, name))



"""\
PEP INFO

PEP 326 -- A Case for Top and Bottom Values
Status: Rejected
Created: 2003-12-20

MODULE INFO

This module implements the Min (UniversalMinimum) and Max (UniversalMaximum)
singletons specified in PEP 326.

REFERENCES

PEP 326: <https://www.python.org/dev/peps/pep-0326/>
"""
PEP = 326

class _singleton(type):
    # PEP 326 says Min and Max are singletons like None
    _instances = {}
    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super().__call__(*args, **kwargs)
        return cls._instances[cls]
# The reference implementation is not used because
# 1) __cmp__ is removed
# 2) It's not a singleton in the reference implementation
class MinType(metaclass=_singleton):
    def __lt__(self, other) -> bool:
        return True
    __le__ = __lt__
    def __gt__(self, other) -> bool:
        return False
    def __eq__(self, other) -> bool:
        # Min is only equal to itself
        return isinstance(other, type(self))
    __ge__ = __eq__
    def __repr__(self) -> str:
        return 'Min'
    __str__ = __repr__
class MaxType(metaclass=_singleton):
    def __gt__(self, other) -> bool:
        return True
    __ge__ = __gt__
    def __lt__(self, other) -> bool:
        return False
    def __eq__(self, other) -> bool:
        # Max is only equal to itself
        return isinstance(other, type(self))
    __le__ = __eq__
    def __repr__(self) -> str:
        return 'Max'
    __str__ = __repr__
# 4 names appeared in PEP 326
Min = UniversalMinimum = MinType()
Max = UniversalMaximum = MaxType()



"""\
PEP INFO

PEP 754 -- IEEE 754 Floating Point Special Values
Status: Rejected
Created: 2003-03-28

MODULE INFO

This module implements NaN, PosInf, NegInf and the functions 
in PEP 754.

REFERENCES

PEP 754: <https://www.python.org/dev/peps/pep-0754/>
"""
PEP = 754
import math as _math

NaN = float('nan')
PosInf = float('inf')
NegInf = -PosInf
def isNaN(value) -> bool:
    return _math.isnan(value)
def isPosInf(value) -> bool:
    return _math.isinf(value) and value > 0
def isNegInf(value) -> bool:
    return _math.isinf(value) and value < 0
def isFinite(value) -> bool:
    return _math.isfinite(value)
def isInf(value) -> bool:
    return _math.isinf(value)



import sys
try:
    from . import pep211 as _p
except ImportError:
    import pep211 as _p
class pep204:
    """\
PEP INFO

PEP 204 -- Range Literals
Status: Rejected
Created: 2000-07-14

MODULE INFO

This module supports indexing for range literals:
>>> import rejected_peps.pep204 as r
>>> r[5]
range(0, 5)
>>> r[2:5]
range(2, 5)
>>> r[60:40:-2]
range(60, 40, -2)

REFERENCES

PEP 204: <https://www.python.org/dev/peps/pep-204/>
"""
    PEP = 204
    def __getitem__(self, x) -> range:
        if isinstance(x, slice):
            start, stop, step = x.start, x.stop, x.step
            if stop is None:
                raise ValueError('Stop is required')
            if start is None:
                start = 0
            if step is None:
                step = 1
            return range(start, stop, step)
        return range(x)
    def __repr__(self) -> str:
        return repr(_p).replace('pep211', 'pep204')
sys.modules[__name__] = pep204()



"""\
PEP INFO

PEP 276 -- Simple Iterator for ints
Status: Rejected
Created: 2001-11-12

MODULE INFO

This module implements the iterable IntType in PEP 276.

REFERENCES

PEP 276: <https://www.python.org/dev/peps/pep-0276/>
"""
PEP = 276
import builtins as _b

class IntType(_b.int):
    def __iter__(self):
        if self < 0:
            return iter(())
        return iter(range(_b.int(self)))
int = IntType



import rejected_peps
import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    long_description = f.read()

setuptools.setup(
    name="rejected-peps",
    version=rejected_peps.__version__,
    author="wyz23x2",
    author_email="wyz23x2@163.com",
    description="A Python package that implements some rejected, deferred or withdrawn PEPs.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/wyz23x2/rejected-peps/",
    project_urls={
        "Bug Tracker": "https://github.com/wyz23x2/rejected-peps/issues",
        "Changelog": "https://github.com/wyz23x2/rejected-peps/blob/main/CHANGELOG.md"
    },
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: MIT License",
        "Typing :: Typed",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
)


"""\
PEP INFO

PEP 212 -- Loop Counter Iteration
Status: Rejected
Created: 2000-08-22

MODULE INFO

This module implements solution #2 of PEP 212,
i.e. the indices() and irange() functions.
Note that irange() is exactly the same to PEP 279's enumerate().

REFERENCES

PEP 212: <https://www.python.org/dev/peps/pep-0212/>
Related:
PEP 279: <https://www.python.org/dev/peps/pep-0279/>
"""
PEP = 212
from typing import Sequence as _Seq

def indices(sequence: _Seq) -> range:
    return range(len(sequence))
irange = enumerate



"""\
PEP INFO

PEP 3140 -- str(container) should call str(item), not repr(item)
Status: Rejected
Created: 2008-05-27

MODULE INFO

This module changes str() to a function matching behavior 
described in the PEP.

REFERENCES

PEP 3140: <https://www.python.org/dev/peps/pep-3140/>
"""
PEP = 3140
import builtins as _b
from collections.abc import Container as _C, Mapping as _M

def str(x, *args, **kwargs) -> _b.str:
    if args or kwargs:
        return _b.str(x, *args, **kwargs)
    if (not isinstance(x, _C)) or isinstance(x, (_b.str, bytes)):
        xs = getattr(x, '__str__', None)
        if xs is not None:
            value = xs()
            if value is not NotImplemented:
                return value
        return x.__repr__()
    if isinstance(x, (dict, _M)):
        if isinstance(x, dict):
            prefix = suffix = ''
        else:
            prefix, suffix = f'{type(x).__name__}(', ')'
        if not x:
            return '%s{}%s' % (prefix, suffix)
        parts = [prefix, '{']
        for key, value in x.items():
            parts.extend((f'{key!s}: {value!s}', ', '))
        parts = [*parts[:-1], '}', suffix]
        return ''.join(parts)
    else:
        cls = type(x)
        prefix, suffix = {list: ('[', ']'),
                          tuple: ('(', ')'),
                          set: ('{', '}'),
                          }.get(cls, (f'{cls.__name__}([', '])'))
        parts = [prefix]
        for item in x:
            parts.extend((str(item), ', '))
        if not (isinstance(x, tuple) and len(x) == 1):
            if len(x):
                parts = parts[:-1]
        else:
            parts[-1] = ','
        return ''.join((*parts, suffix))
